#include <zephyr.h>
#include <sys/printk.h>
#include <stdio.h>
#include <string.h>
#include <shell/shell.h>
#include <shell/shell_uart.h>
#include <version.h>
#include <logging/log.h>
#include <stdlib.h>
#include <device.h>
#include <drivers/gpio.h>
#include <console/console.h>

#define WATCHDOG_STACK_SIZE		500
#define WATCHDOG_PRIORITY		5

#define WATCHDOG_WAKE			1000

struct device *watchdog_dev;

K_THREAD_STACK_DEFINE( watchdog_stack_area, WATCHDOG_STACK_SIZE );
struct k_thread watchdog_thread_data;
k_tid_t	watchdog_tid;								// ThreadID


#define PIN_1 6
#define PIN_2 7
#define PIN_3 8

static struct device *gpio_dev;

/* 
** Function: 		watchdog
** Description: 	Actual watchdog thread routine.
*/
void 
watchdog( 
	void *unused1, 
	void *unused2, 
	void *unused3 )
{
	while (1) {
		printk("+");	
		gpio_pin_toggle(gpio_dev,PIN_1);
		gpio_pin_toggle(gpio_dev,PIN_2);
		gpio_pin_toggle(gpio_dev,PIN_3);
		k_sleep( WATCHDOG_WAKE );

	}
}

/*
** Function:		start_watchdog Description: 	Starts the
** watchdog routine thread
*/
int 
start_watchdog()
{

	//watchdog_dev = device_get_binding("GPIO_0");
//
//	ret = gpio_pin_configure(watchdog_dev, LED_PIN, GPIO_OUTPUT_ACTIVE | FLAGS);
//	if (ret < 0) {
//		return(1);
//	}
//	gpio_pin_set( watchdog_dev, LED_PIN, (int)false);
//

	watchdog_tid = k_thread_create(&watchdog_thread_data, 
								   watchdog_stack_area,
								   K_THREAD_STACK_SIZEOF( watchdog_stack_area ),
								   watchdog,
								   NULL, NULL, NULL,
								   WATCHDOG_PRIORITY,
								   0,
								   K_NO_WAIT );


	return(0);
}


/*
** Function:		stop_watchdog
** Description: 	Stop the watchdog function thread
*/
int
stop_watchdog()
{
	return(0);
}


void main( void )
{
	int err;
	console_init();

	printk("GPIO Test Program\n");

	gpio_dev = device_get_binding(DT_LABEL(DT_NODELABEL(gpio0)));
	if (gpio_dev == NULL) {
		printk("GPIO_0 bind error");
		return;
	}
	
	
	err = gpio_pin_configure(gpio_dev, PIN_1,
				GPIO_OUTPUT | GPIO_OUTPUT_INIT_LOW);	
	if (err) {
		printk("PIN_1 config error: %d", err);
	}
	
	err = gpio_pin_configure(gpio_dev, PIN_2,
				GPIO_OUTPUT | GPIO_OUTPUT_INIT_LOW);	
	if (err) {
		printk("PIN_2 config error: %d", err);
	}
	
	err = gpio_pin_configure(gpio_dev, PIN_3,
				GPIO_OUTPUT | GPIO_OUTPUT_INIT_LOW);	
	if (err) {
		printk("PIN_3 config error: %d", err);
	}

	start_watchdog();

	for(;;)
	{
		printk("-");
		k_sleep(500);

	}
}